@@ -1,4 +1,4 @@
-/* $Id: menueditor-main-window.c 22742 2006-08-13 10:15:44Z pollux $ */
+/* $Id: menueditor-main-window.c 23114 2006-09-09 13:35:41Z pollux $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -822,7 +822,9 @@ action_edit (GtkAction *action, MenuEditorMainWindow *window)
     
       if (selected_icon) {
         new_icon = xfce_themed_icon_load (selected_icon, ICON_SIZE);    
-      }
+      } else {
+		new_icon = xfce_inline_icon_at_size (dummy_icon_data, ICON_SIZE, ICON_SIZE);
+	  }
       new_option_1 = g_strdup (selected_icon);
     
       switch (type) {
@@ -2172,9 +2174,17 @@ cb_treeview_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc,
     }
     
     gtk_tree_model_get_iter (model, &iter_source, path_source);
-    gtk_tree_path_free (path_source);
     gtk_tree_model_get_iter (model, &iter_where_insert, path_where_insert);
-
+    
+    if (gtk_tree_path_is_descendant (path_where_insert, path_source) 
+        || gtk_tree_path_compare (path_where_insert, path_source) == 0) {
+      gtk_tree_path_free (path_source);
+      goto cleanup;
+    }
+    
+    gtk_tree_path_free (path_source);
+    
+    
     gtk_tree_model_get (model, &iter_where_insert, COLUMN_TYPE, &type, -1);
 
     if ((type == MENU) || (position == GTK_TREE_VIEW_DROP_BEFORE) || (position == GTK_TREE_VIEW_DROP_AFTER)) {
