@@ -2,7 +2,7 @@
  *  
  *  Copyright (C) 2003 Jasper Huijsmans (huysmans@users.sourceforge.net)
  *  Copyright (C) 2003,2006 Benedikt Meurer <benny@xfce.org>
- *  Copyright (c) 2004 Brian Tarricone <bjt23@cornell.edu>
+ *  Copyright (c) 2004-2006 Brian Tarricone <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -57,6 +57,10 @@
 #endif
 #include <gtk/gtk.h>
 
+#ifdef HAVE_LIBEXO
+#include <exo/exo.h>
+#endif
+
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 #include <xfce-mcs-manager/manager-plugin.h>
@@ -241,10 +245,10 @@ backdrop_create_channel (McsPlugin * mcs_plugin)
                 bp->color1.blue = setting->data.v_color.blue;
                 bp->color1.alpha = setting->data.v_color.alpha;
             } else {
-                /* Just a color by default #233322 */
-                bp->color1.red = (guint16)0x2300;
-                bp->color1.green = (guint16)0x3300;
-                bp->color1.blue = (guint16)0x2200;
+                /* Just a color by default #3b5b89 */
+                bp->color1.red = (guint16)0x3b00;
+                bp->color1.green = (guint16)0x5b00;
+                bp->color1.blue = (guint16)0x8900;
                 bp->color1.alpha = (guint16)0xffff;
                 mcs_manager_set_color(mcs_plugin->manager, setting_name,
                         BACKDROP_CHANNEL, &bp->color1);
@@ -260,10 +264,10 @@ backdrop_create_channel (McsPlugin * mcs_plugin)
                 bp->color2.blue = setting->data.v_color.blue;
                 bp->color2.alpha = setting->data.v_color.alpha;
             } else {
-                /* Just a color by default #56972E */
-                bp->color2.red = (guint16)0x5600;
-                bp->color2.green = (guint16)0x9700;
-                bp->color2.blue = (guint16)0x2E00;
+                /* Just a color by default #3e689e */
+                bp->color2.red = (guint16)0x3e00;
+                bp->color2.green = (guint16)0x6800;
+                bp->color2.blue = (guint16)0x9e00;
                 bp->color2.alpha = (guint16)0xffff;
                 mcs_manager_set_color(mcs_plugin->manager, setting_name,
                         BACKDROP_CHANNEL, &bp->color2);
@@ -275,9 +279,9 @@ backdrop_create_channel (McsPlugin * mcs_plugin)
             if(setting)
                 bp->show_image = setting->data.v_int == 0 ? FALSE : TRUE;
             else {
-                bp->show_image = TRUE;
+                bp->show_image = FALSE;
                 mcs_manager_set_int(mcs_plugin->manager, setting_name,
-                        BACKDROP_CHANNEL, 1);
+                        BACKDROP_CHANNEL, 0);
             }
             
             /* the color style */
@@ -287,7 +291,7 @@ backdrop_create_channel (McsPlugin * mcs_plugin)
             if(setting)
                 bp->color_style = setting->data.v_int;
             else {
-                bp->color_style = XFCE_BACKDROP_COLOR_HORIZ_GRADIENT;
+                bp->color_style = XFCE_BACKDROP_COLOR_SOLID;
                 mcs_manager_set_int(mcs_plugin->manager, setting_name,
                         BACKDROP_CHANNEL, bp->color_style);
             }
@@ -496,6 +500,7 @@ file_entry_lost_focus (GtkWidget * entry, GdkEventFocus * ev,
     return FALSE;
 }
 
+#ifndef HAVE_LIBEXO
 static void
 update_preview_cb(GtkFileChooser *chooser, gpointer data)
 {
@@ -516,11 +521,15 @@ update_preview_cb(GtkFileChooser *chooser, gpointer data)
     }
     gtk_file_chooser_set_preview_widget_active(chooser, (pix != NULL));
 }
+#endif
 
 static void
 browse_cb(GtkWidget *b, BackdropPanel *bp)
 {
-    GtkWidget *chooser, *preview;
+    GtkWidget *chooser;
+#ifndef HAVE_LIBEXO
+    GtkWidget *preview;
+#endif
     GtkFileFilter *filter;
     gchar *confdir;
     
@@ -565,12 +574,16 @@ browse_cb(GtkWidget *b, BackdropPanel *bp)
         g_free(tmppath);
     }
     
+#ifdef HAVE_LIBEXO
+    exo_gtk_file_chooser_add_thumbnail_preview(GTK_FILE_CHOOSER(chooser));
+#else
     preview = gtk_image_new();
     gtk_widget_show(preview);
     gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER(chooser), preview);
     gtk_file_chooser_set_preview_widget_active(GTK_FILE_CHOOSER(chooser), FALSE);
     g_signal_connect(G_OBJECT(chooser), "update-preview",
                      G_CALLBACK(update_preview_cb), preview);
+#endif
     
     gtk_widget_show(chooser);
     if(gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
@@ -783,6 +796,8 @@ static void
 manage_desktop_chk_toggled_cb(GtkToggleButton *tb, gpointer user_data)
 {
     BackdropDialog *bd = user_data;
+    const gchar *setting_name;
+    McsSetting *setting = NULL;
     
     if(gtk_toggle_button_get_active(tb)) {
         GError *err = NULL;
@@ -810,51 +825,59 @@ manage_desktop_chk_toggled_cb(GtkToggleButton *tb, gpointer user_data)
             g_free(secondary);
         } else
             gtk_widget_set_sensitive(bd->top_notebook, TRUE);
+        
+        setting_name = "managedesktop-show-warning-on";
     } else {
         Window xid;
-        McsSetting *setting;
         
         if(xfdesktop_check_is_running(&xid))
             xfdesktop_send_client_message(xid, QUIT_MESSAGE);
         gtk_widget_set_sensitive(bd->top_notebook, FALSE);
         
-        setting = mcs_manager_setting_lookup(bd->plugin->manager,
-                "managedesktop-show-warning", BACKDROP_CHANNEL);
-        if(!setting || setting->data.v_int) {
-            GtkWidget *dlg, *lbl, *chk, *vbox;
-            
-            dlg = gtk_dialog_new_with_buttons(_("Information"),
-                    GTK_WINDOW(bd->dialog),
-                    GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
-                    GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
-            
-            vbox = gtk_vbox_new(FALSE, BORDER);
-            gtk_container_set_border_width(GTK_CONTAINER(vbox), BORDER);
-            gtk_widget_show(vbox);
-            gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), vbox, TRUE, TRUE, 0);
-            
+        setting_name = "managedesktop-show-warning";
+    }
+    
+    setting = mcs_manager_setting_lookup(bd->plugin->manager,
+            setting_name, BACKDROP_CHANNEL);
+    if(!setting || setting->data.v_int) {
+        GtkWidget *dlg, *lbl, *chk, *vbox;
+        
+        dlg = gtk_dialog_new_with_buttons(_("Information"),
+                GTK_WINDOW(bd->dialog),
+                GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
+                GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
+        
+        vbox = gtk_vbox_new(FALSE, BORDER);
+        gtk_container_set_border_width(GTK_CONTAINER(vbox), BORDER);
+        gtk_widget_show(vbox);
+        gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), vbox, TRUE, TRUE, 0);
+        
+        /* FIXME: i'm avoiding changing a string here.  after the string is
+         * translated, remove the second string and replace it with the first */
+        if(!strcmp(setting_name, "managedesktp-show-warning-on"))
+            lbl = gtk_label_new(_("To ensure that this setting takes effect the next time you start Xfce, please be sure to save your session when logging out.  If you are not using the Xfce Session Manager (xfce4-session), you will need to manually edit your ~/.config/xfce4/xinitrc file.  Details are available in the documentation provided on http://xfce.org/."));
+        else
             lbl = gtk_label_new(_("To ensure that Xfce does not manage your desktop the next time you start Xfce, please be sure to save your session when logging out.  If you are not using the Xfce Session Manager (xfce4-session), you will need to manually edit your ~/.config/xfce4/xinitrc file.  Details are available in the documentation provided on http://xfce.org/."));
-            gtk_label_set_line_wrap(GTK_LABEL(lbl), TRUE);
-            gtk_misc_set_alignment(GTK_MISC(lbl), 0.0, 0.5);
-            gtk_widget_show(lbl);
-            gtk_box_pack_start(GTK_BOX(vbox), lbl, FALSE, FALSE, 0);
-            
-            add_spacer(GTK_BOX(vbox));
-            
-            chk = gtk_check_button_new_with_mnemonic(_("_Do not show this again"));
-            gtk_widget_show(chk);
-            gtk_box_pack_start(GTK_BOX(vbox), chk, FALSE, FALSE, 0);
-            
-            gtk_dialog_run(GTK_DIALOG(dlg));
-            
-            if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chk))) {
-                mcs_manager_set_int(bd->plugin->manager,
-                        "managedesktop-show-warning", BACKDROP_CHANNEL, 0);
-                backdrop_write_options(bd->plugin);
-            }
-            
-            gtk_widget_destroy(dlg);
+        gtk_label_set_line_wrap(GTK_LABEL(lbl), TRUE);
+        gtk_misc_set_alignment(GTK_MISC(lbl), 0.0, 0.5);
+        gtk_widget_show(lbl);
+        gtk_box_pack_start(GTK_BOX(vbox), lbl, FALSE, FALSE, 0);
+        
+        add_spacer(GTK_BOX(vbox));
+        
+        chk = gtk_check_button_new_with_mnemonic(_("_Do not show this again"));
+        gtk_widget_show(chk);
+        gtk_box_pack_start(GTK_BOX(vbox), chk, FALSE, FALSE, 0);
+        
+        gtk_dialog_run(GTK_DIALOG(dlg));
+        
+        if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chk))) {
+            mcs_manager_set_int(bd->plugin->manager, setting_name,
+                                BACKDROP_CHANNEL, 0);
+            backdrop_write_options(bd->plugin);
         }
+        
+        gtk_widget_destroy(dlg);
     }
 }
 
